@@ -10,7 +10,6 @@ import numpy as np
 import tinydb
 from tinydb import where
 from scipy.stats import norm
-
 from pycalphad.plot.eqplot import _map_coord_to_variable
 from pycalphad import Database, Model, ReferenceState, variables as v
 from pycalphad.core.equilibrium import _eqcalculate
@@ -21,6 +20,9 @@ from pycalphad.core.phase_rec import PhaseRecord
 from espei.utils import PickleableTinyDB
 from espei.shadow_functions import equilibrium_, calculate_, no_op_equilibrium_, update_phase_record_parameters
 
+_log = logging.getLogger(__name__)
+
+
 EqPropData = NamedTuple('EqPropData', (('dbf', Database),
                                        ('species', Sequence[v.Species]),
                                        ('phases', Sequence[str]),
@@ -199,8 +201,8 @@ def calc_prop_differences(eqpropdata: EqPropData,
     update_phase_record_parameters(phase_records, parameters)
     params_dict = OrderedDict(zip(map(str, eqpropdata.params_keys), parameters))
     output = eqpropdata.output
-    weights = np.array(eqpropdata.weight, dtype=np.float)
-    samples = np.array(eqpropdata.samples, dtype=np.float)
+    weights = np.array(eqpropdata.weight, dtype=np.float_)
+    samples = np.array(eqpropdata.samples, dtype=np.float_)
 
     calculated_data = []
     for comp_conds in eqpropdata.composition_conds:
@@ -218,12 +220,12 @@ def calc_prop_differences(eqpropdata: EqPropData,
         vals = getattr(propdata, output).flatten().tolist()
         calculated_data.extend(vals)
 
-    calculated_data = np.array(calculated_data, dtype=np.float)
+    calculated_data = np.array(calculated_data, dtype=np.float_)
 
     assert calculated_data.shape == samples.shape, f"Calculated data shape {calculated_data.shape} does not match samples shape {samples.shape}"
     assert calculated_data.shape == weights.shape, f"Calculated data shape {calculated_data.shape} does not match weights shape {weights.shape}"
     differences = calculated_data - samples
-    logging.debug(f'Equilibrium thermochemical error - output: {output} differences: {differences}, weights: {weights}, reference: {eqpropdata.reference}')
+    _log.debug('Output: %s differences: %s, weights: %s, reference: %s', output, differences, weights, eqpropdata.reference)
     return differences, weights
 
 
